==> libecalc-8.23.1-py3-none-any.whl: libecalc/fixtures/cases/ltp_export/loading_storage_ltp_yaml.py <==
from typing import List

import yaml

from libecalc.common.utils.rates import RateType
from libecalc.dto import Asset
from libecalc.presentation.yaml.parse_input import map_yaml_to_dto
from libecalc.presentation.yaml.yaml_models.pyyaml_yaml_model import PyYamlYamlModel


def ltp_oil_loaded_yaml_factory(
    emission_factor: float,
    rate_types: List[RateType],
    fuel_rates: List[float],
    emission_name: str,
    regularity: float,
    categories: List[str],
    consumer_names: List[str],
) -> Asset:
    input_text = f"""
    FUEL_TYPES:
    - NAME: fuel
      EMISSIONS:
      - NAME: {emission_name}
        FACTOR: {emission_factor}

    INSTALLATIONS:
    - NAME: minimal_installation
      HCEXPORT: 0
      FUEL: fuel
      CATEGORY: FIXED
      REGULARITY: {regularity}

      FUELCONSUMERS:
      {create_direct_consumers_yaml(categories, fuel_rates, rate_types, consumer_names)}

    """

    create_direct_consumers_yaml(categories, fuel_rates, rate_types, consumer_names)
    yaml_text = yaml.safe_load(input_text)
    configuration = PyYamlYamlModel(
        internal_datamodel=yaml_text,
        name="test",
        instantiated_through_read=True,
    )
    yaml_model = map_yaml_to_dto(configuration=configuration, resources={})
    return yaml_model


def create_direct_consumers_yaml(
    categories: List[str], fuel_rates: List[float], rate_types: List[RateType], consumer_names: List[str]
) -> str:
    consumers = ""
    for category, fuel_rate, rate_type, consumer_name in zip(categories, fuel_rates, rate_types, consumer_names):
        consumer = f"""
        - NAME: {consumer_name}
          CATEGORY: {category}
          FUEL: fuel
          ENERGY_USAGE_MODEL:
            TYPE: DIRECT
            FUELRATE: {fuel_rate}
            CONSUMPTION_RATE_TYPE: {rate_type.value}
        """
        consumers = consumers + consumer
    return consumers

==> libecalc-9.0.0-py3-none-any.whl: libecalc/fixtures/cases/ltp_export/loading_storage_ltp_yaml.py <==
import yaml

from libecalc.common.utils.rates import RateType
from libecalc.dto import Asset
from libecalc.presentation.yaml.parse_input import map_yaml_to_dto
from libecalc.presentation.yaml.yaml_models.pyyaml_yaml_model import PyYamlYamlModel


def ltp_oil_loaded_yaml_factory(
    emission_factor: float,
    rate_types: list[RateType],
    fuel_rates: list[float],
    emission_name: str,
    regularity: float,
    categories: list[str],
    consumer_names: list[str],
) -> Asset:
    input_text = f"""
    FUEL_TYPES:
    - NAME: fuel
      EMISSIONS:
      - NAME: {emission_name}
        FACTOR: {emission_factor}

    INSTALLATIONS:
    - NAME: minimal_installation
      HCEXPORT: 0
      FUEL: fuel
      CATEGORY: FIXED
      REGULARITY: {regularity}

      FUELCONSUMERS:
      {create_direct_consumers_yaml(categories, fuel_rates, rate_types, consumer_names)}

    """

    create_direct_consumers_yaml(categories, fuel_rates, rate_types, consumer_names)
    yaml_text = yaml.safe_load(input_text)
    configuration = PyYamlYamlModel(
        internal_datamodel=yaml_text,
        name="test",
        instantiated_through_read=True,
    )
    yaml_model = map_yaml_to_dto(configuration=configuration, resources={})
    return yaml_model


def create_direct_consumers_yaml(
    categories: list[str], fuel_rates: list[float], rate_types: list[RateType], consumer_names: list[str]
) -> str:
    consumers = ""
    for category, fuel_rate, rate_type, consumer_name in zip(categories, fuel_rates, rate_types, consumer_names):
        consumer = f"""
        - NAME: {consumer_name}
          CATEGORY: {category}
          FUEL: fuel
          ENERGY_USAGE_MODEL:
            TYPE: DIRECT
            FUELRATE: {fuel_rate}
            CONSUMPTION_RATE_TYPE: {rate_type.value}
        """
        consumers = consumers + consumer
    return consumers
